@@ -90,7 +90,8 @@ class ObjectDBIndex(ObjectDBIndexBase):
     ):  # pylint: disable=super-init-not-called
         from dvc_objects.fs import LocalFileSystem
         from dvc_objects.fs.utils import makedirs
-        from dvc_objects.hashfile.cache import Cache, Index
+
+        from ..hashfile.cache import Cache, Index
 
         self.index_dir = os.path.join(tmp_dir, self.INDEX_DIR, name)
         makedirs(self.index_dir, exist_ok=True)
@@ -110,7 +111,7 @@ class ObjectDBIndex(ObjectDBIndexBase):
 
     def clear(self):
         """Clear this index (to force re-indexing later)."""
-        from dvc_objects.hashfile.cache import Timeout
+        from ..hashfile.cache import Timeout
 
         try:
             self.index.clear()
@@ -119,7 +120,7 @@ class ObjectDBIndex(ObjectDBIndexBase):
 
     def update(self, dir_hashes: Iterable[str], file_hashes: Iterable[str]):
         """Update this index, adding the specified hashes."""
-        from dvc_objects.hashfile.cache import Timeout
+        from ..hashfile.cache import Timeout
 
         try:
             with self.index.transact():
